@@ -189,7 +189,7 @@ class BusWatch(object):
             self.box_bus.remove(childs[-1])
 
         try:
-            del(self.__addr_info)
+            del self.__addr_info
         except AttributeError:
             pass
 
